==> em_celery-0.1.1-py2.py3-none-any.whl: em_celery/tools/shopify_product_upload_task_sender.py <==
# -*- coding: utf-8 -*-

import os
import time
import logging
import logging.handlers
import json

import click
from kombu import Connection

from em_celery import logger
from em_celery.tasks.shopify_upload_product_task import upload_shopify_product


@click.command('Send shopify product upload task to worker.')
@click.option('-b', '--broker_url', type=str, required=True, help='Celery worker broker URL.')
@click.option('-q', '--qps', type=float, help='Quantity per second (QPS) to send task.')
@click.option('-s', '--store_code', type=str, required=True, help='Store code that products shall be uploaded to.')
@click.argument('products_path')
def send_shopify_product_upload_task(products_path, store_code, broker_url, qps):
  products_path = os.path.abspath(os.path.expanduser(products_path))
  if not os.path.isfile(products_path):
    logger.error('Could not find products file {}'.format(products_path))
    return

  log_dir = os.path.join(os.path.expanduser('~'), '.em_celery', 'logs')
  if not os.path.isdir(log_dir):
    os.makedirs(log_dir)
  log_path = os.path.join(log_dir, 'shopify_product_upload_task_sender.log')
  level = logging.INFO
  max_bytes = 20 * 1024 ** 2
  fh = logging.handlers.RotatingFileHandler(
    log_path, maxBytes=max_bytes, backupCount=5)
  fh.setLevel(level)
  formatter = logging.Formatter('%(asctime)s %(name)s [%(levelname)s]:%(message)s')
  fh.setFormatter(formatter)
  logger.addHandler(fh)

  last_send_time = None
  connection = Connection(broker_url)
  queue = 'ShopifyProductUpload'
  with open(products_path, encoding='utf-8', errors='ignore') as fh:
    for line in fh:
      s = line.strip()
      if not s:
        continue

      prod = json.loads(s)
      if last_send_time:
        wait_time = 1 / qps - (time.time() - last_send_time)
        if wait_time > 0:
          logger.debug("Waiting %.3fs to send next message", wait_time)
          time.sleep(wait_time)

      last_send_time = time.time()

      upload_shopify_product.apply_async(
        args=(store_code, prod),
        queue=queue,
        connection=connection)
      logger.debug(
        'Added upload_shopify_product(%s, %s)',
        store_code, prod)

if __name__ == "__main__":
  send_shopify_product_upload_task()

==> em_celery-0.1.10-py2.py3-none-any.whl: em_celery/tools/shopify_product_upload_task_sender.py <==
# -*- coding: utf-8 -*-

import os
import time
import logging
import logging.handlers
import json

import click
from kombu import Connection

from em_celery import logger
from em_celery.tasks.shopify_upload_product_task import upload_shopify_product


@click.command('Send shopify product upload task to worker.')
@click.option('-b', '--broker_url', type=str, required=True, help='Celery worker broker URL.')
@click.option('-q', '--qps', type=float, help='Quantity per second (QPS) to send task.')
@click.option('-s', '--store_code', type=str, required=True, help='Store code that products shall be uploaded to.')
@click.option('-sid', '--seller_id', type=str, required=True, help='Seller that products belongs to.')
@click.argument('products_path')
def send_shopify_product_upload_task(products_path, store_code, seller_id, broker_url, qps):
  products_path = os.path.abspath(os.path.expanduser(products_path))
  if not os.path.isfile(products_path):
    logger.error('Could not find products file {}'.format(products_path))
    return

  log_dir = os.path.join(os.path.expanduser('~'), '.em_celery', 'logs')
  if not os.path.isdir(log_dir):
    os.makedirs(log_dir)
  log_path = os.path.join(log_dir, 'shopify_product_upload_task_sender.log')
  level = logging.INFO
  max_bytes = 20 * 1024 ** 2
  fh = logging.handlers.RotatingFileHandler(
    log_path, maxBytes=max_bytes, backupCount=5)
  fh.setLevel(level)
  formatter = logging.Formatter('%(asctime)s %(name)s [%(levelname)s]:%(message)s')
  fh.setFormatter(formatter)
  logger.addHandler(fh)

  last_send_time = None
  connection = Connection(broker_url)
  queue = 'ShopifyProductUpload'
  with open(products_path, encoding='utf-8', errors='ignore') as fh:
    for line in fh:
      s = line.strip()
      if not s:
        continue

      prod = json.loads(s)
      if 'seller_id' not in prod or not prod['seller_id']:
        prod['seller_id'] = seller_id

      if last_send_time:
        wait_time = 1 / qps - (time.time() - last_send_time)
        if wait_time > 0:
          logger.debug("Waiting %.3fs to send next message", wait_time)
          time.sleep(wait_time)

      last_send_time = time.time()

      upload_shopify_product.apply_async(
        args=(store_code, prod),
        queue=queue,
        connection=connection)
      logger.debug(
        'Added upload_shopify_product(%s, %s)',
        store_code, prod)

if __name__ == "__main__":
  send_shopify_product_upload_task()
